# Decentralized Stochastic Gradient Langevin Diffusion


This repo is to build the package for decentralized stochastic gradient Langevin diffusion. For more details please
visit this https://mrislambd.github.io/desgld_package/
